### 简介

qtlink是对pyside6的部分组件的封装，目前涉及的组件有表格/对话框/matplotlib绘图等。

### 安装

```
pip install qtlink
# 或者使用清华源
pip install qtlink -i https://pypi.tuna.tsinghua.edu.cn/simple
```

### 文档

[qtlink文档](https://p.kdocs.cn/s/SZIEWJAYAAQGU)

### 示例

cases文件夹中包含了可运行的多个用法示例。
